ActiveConnection

Struct ActiveConnection 

pub struct ActiveConnection<'a, C: WebsocketClientCallback> {
    pub client: Ref<CoreWebsocketClient>,
    /* private fields */
}
Represents a live websocket connection.

This manages the lifetime of the callback, ensuring it outlives the connection.

Fields

client: Ref<CoreWebsocketClient>

Methods from Deref<Target = CoreWebsocketClient>

pub fn notify_connected(&self) -> bool

Call the connect callback function, forward the callback returned value

pub fn notify_disconnected(&self)

Notify the callback function of a disconnect. This must be called at the end of an active websocket connection lifecycle, to free resources.

NOTE: This does not actually disconnect, use the Self::disconnect function for that.

pub fn notify_error(&self, msg: &str)

Call the error callback function, this is not a terminating request you must use CoreWebsocketClient::notify_disconnected to terminate the connection.

pub fn notify_read(&self, data: &[u8]) -> bool

Call the read callback function, forward the callback returned value.

pub fn write(&self, data: &[u8]) -> bool

pub fn disconnect(&self) -> bool