pub struct CoreWebsocketClient { /* private fields */ }Expand description
Implements a websocket client.
To connect, use Ref<CoreWebsocketClient>::connect which will return an ActiveConnection
which manages the lifecycle of the websocket connection.
Implementations
Sourceimpl CoreWebsocketClient
impl CoreWebsocketClient
Sourcepub fn notify_connected(&self) -> bool
pub fn notify_connected(&self) -> bool
Call the connect callback function, forward the callback returned value
Sourcepub fn notify_disconnected(&self)
pub fn notify_disconnected(&self)
Notify the callback function of a disconnect. This must be called at the end of an active websocket connection lifecycle, to free resources.
NOTE: This does not actually disconnect, use the Self::disconnect function for that.
Sourcepub fn notify_error(&self, msg: &str)
pub fn notify_error(&self, msg: &str)
Call the error callback function, this is not a terminating request you must use
CoreWebsocketClient::notify_disconnected to terminate the connection.
Sourcepub fn notify_read(&self, data: &[u8]) -> bool
pub fn notify_read(&self, data: &[u8]) -> bool
Call the read callback function, forward the callback returned value.
pub fn write(&self, data: &[u8]) -> bool
pub fn disconnect(&self) -> bool